import { Component, OnInit, AfterViewInit, AfterContentInit, Input } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { Infra } from 'packages/infra/model';
import { Store, select } from '@ngrx/store';
import { ListSelector } from 'packages/infra/store';
import * as InfraListStore from 'packages/infra/store/list';
import { Page, PageParams } from 'app/commons/model';
import { RPCClientError } from '@loafer/ng-rpc/protocol';
import { Probe } from 'packages/probe/model';

import * as ProbeDetailStore from 'packages/probe/store/detail';
import { DetailSelector as ProbeDetailSelector } from 'packages/probe/store';
import { Target } from '../../model';


@Component({
    selector: 'of-target-list',
    templateUrl: './list.component.html',
})
export class ListComponent implements OnInit, AfterContentInit {

    probe$ = this.probeDetailStore.pipe(select(ProbeDetailSelector.select('probe')));
    infras$ = this.infraListStore.pipe(select(ListSelector.select('page')));
    infras: Infra[];
    probe: Probe;
    target: Target = null;
    sensorSettingDisplay = false;

    constructor(
        private route: ActivatedRoute,
        private router: Router,
        private infraListStore: Store<InfraListStore.State>,
        private probeDetailStore: Store<ProbeDetailStore.State>,
    ) {
    }

    ngOnInit() {
        // this.probe$.subscribe(
        //     (probe: Probe) => {
        //         if (probe) {
        //             console.log(probe);
        //             this.probe = probe;
        //             this.getInfras(probe);
        //         }
        //     },
        //     (error: RPCClientError) => {
        //         console.log(error.response.message);
        //     }
        // );

        // this.infras$.subscribe(
        //     (page: Page) => {
        //         if (!page) {
        //             return;
        //         }
        //         this.infras = page.content;
        //     },
        //     (error: RPCClientError) => {
        //         console.log(error);
        //     }
        // );
    }

    ngAfterContentInit() {
        const probeId = this.route.snapshot.paramMap.get('id');
        this.getProbe(probeId);

        // Temporary
        const infra1 = {
            id: 1,
            infraType: {
                id: 1
            },
            target: {
                id: 1,
                displayName: 'FakeTarget1',
            },
        };
        const infra2 = {
            id: 2,
            infraType: {
                id: 3
            },
            target: {
                id: 2,
                displayName: 'FakeTarget2',
            },
        };
        const infra3 = {
            id: 3,
            infraType: {
                id: 2
            },
            target: {
                id: 3,
                displayName: 'FakeTarget3',
            },
        };
        this.infras = [];
        this.infras.push(infra1);
        this.infras.push(infra2);
        this.infras.push(infra3);
    }

    getProbe(probeId: string) {
        this.probeDetailStore.dispatch(
            new ProbeDetailStore.Read(
                { id: probeId }
            )
        );
    }
    getInfras(probe) {
        const pageParams: PageParams = {
            pageNo: '0',
            countPerPage: '10',
            sortCol: 'id',
            sortDirection: 'descending'
        };
        this.infraListStore.dispatch(
            new InfraListStore.ReadAllByProbe(
                { probe, pageParams }
            )
        );
    }

    onRowSelect(event) {
        console.log(event.data);
    }

    onAddSensor(target: Target) {
        this.target = target;
        this.sensorSettingDisplay = true;
    }

    onSensorSettingClose() {
        this.sensorSettingDisplay = false;
    }
}
